@@ -3,9 +3,11 @@
 """
 import re
 import sys
+from typing import Any
+from typing import List
+from typing import Type
 
-import six
-
+from .limits import RateLimitItem
 from .limits import GRANULARITIES
 
 SEPARATORS = re.compile(r"[,;|]{1}")
@@ -25,58 +27,63 @@ EXPR = re.compile(
 )
 
 
-def get_dependency(dep):
+def get_dependency(dep) -> Any:
     """
     safe function to import a module programmatically
-    :return: module or None (if not importable)
     """
     try:
         __import__(dep)
+
         return sys.modules[dep]
     except ImportError:  # pragma: no cover
         return None
 
 
-def parse_many(limit_string):
+def parse_many(limit_string: str) -> List[RateLimitItem]:
     """
     parses rate limits in string notation containing multiple rate limits
     (e.g. '1/second; 5/minute')
 
-    :param string limit_string: rate limit string using :ref:`ratelimit-string`
+    :param limit_string: rate limit string using :ref:`ratelimit-string`
     :raise ValueError: if the string notation is invalid.
-    :return: a list of :class:`RateLimitItem` instances.
 
     """
-    if not (isinstance(limit_string, six.string_types) and EXPR.match(limit_string)):
+
+    if not (isinstance(limit_string, str) and EXPR.match(limit_string)):
         raise ValueError("couldn't parse rate limit string '%s'" % limit_string)
     limits = []
+
     for limit in SEPARATORS.split(limit_string):
-        amount, _, multiples, granularity_string = SINGLE_EXPR.match(limit).groups()
-        granularity = granularity_from_string(granularity_string)
-        limits.append(granularity(amount, multiples))
+        match = SINGLE_EXPR.match(limit)
+
+        if match:
+            amount, _, multiples, granularity_string = match.groups()
+            granularity = granularity_from_string(granularity_string)
+            limits.append(granularity(int(amount), multiples and int(multiples) or None))
+
     return limits
 
 
-def parse(limit_string):
+def parse(limit_string: str) -> RateLimitItem:
     """
     parses a single rate limit in string notation
     (e.g. '1/second' or '1 per second'
 
-    :param string limit_string: rate limit string using :ref:`ratelimit-string`
+    :param limit_string: rate limit string using :ref:`ratelimit-string`
     :raise ValueError: if the string notation is invalid.
-    :return: an instance of :class:`RateLimitItem`
 
     """
+
     return list(parse_many(limit_string))[0]
 
 
-def granularity_from_string(granularity_string):
+def granularity_from_string(granularity_string) -> Type[RateLimitItem]:
     """
 
     :param granularity_string:
-    :return: a subclass of :class:`RateLimitItem`
     :raise ValueError:
     """
+
     for granularity in GRANULARITIES.values():
         if granularity.check_granularity_string(granularity_string):
             return granularity
